# asynkio - README <!-- omit in toc -->

<!--
[![CircleCI](https://circleci.com/gh/google/asynkio.svg?style=svg)](https://circleci.com/gh/google/asynkio)
-->
[![License](https://img.shields.io/badge/License-BSD_3--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![PyPI version](https://badge.fury.io/py/asynkio.svg)](https://badge.fury.io/py/asynkio)
![versions](https://img.shields.io/pypi/pyversions/asynkio.svg)
[![Python package](https://github.com/synesissoftware/asynkio/actions/workflows/python-package.yml/badge.svg)](https://github.com/synesissoftware/asynkio/actions/workflows/python-package.yml)
[![Last Commit](https://img.shields.io/github/last-commit/synesissoftware/asynkio)](https://github.com/synesissoftware/asynkio/commits/master)

Tokio-like functionality for Python


## Table of contents <!-- omit in toc -->

- [Introduction](#introduction)
- [Installation \& Usage](#installation--usage)
- [Components](#components)
- [Examples](#examples)
- [Project Information](#project-information)
	- [Where to get help](#where-to-get-help)
	- [Contribution guidelines](#contribution-guidelines)
	- [Dependencies](#dependencies)
	- [Related projects](#related-projects)
	- [License](#license)


## Introduction

**asynkio** - a portmanteau of **asyncio** and **Tokio**, pronounced "ay sink ee-oh" - is a small, simple **Python** library that provides some of the features of the **Rust** **Tokio** library's features, such as `Duration`, `Instant`, and `Interval`.


## Installation & Usage

Install via **pip** or **pip3**, as in:

```
$ pip3 install asynkio
```

Use via **import**:

T.B.C.


## Components

T.B.C.


## Examples

Examples are provided in the ```examples``` directory, along with a markdown description for each. A detailed list TOC of them is provided in [EXAMPLES.md](./EXAMPLES.md).


## Project Information


### Where to get help

[GitHub Page](https://github.com/synesissoftware/asynkio "GitHub Page")


### Contribution guidelines

Defect reports, feature requests, and pull requests are welcome on https://github.com/synesissoftware/asynkio.


### Dependencies

T.B.C.


### Related projects

T.B.C.


### License

**asynkio** is released under the 3-clause BSD license. See [LICENSE](./LICENSE) for details.


<!-- ########################### end of file ########################### -->

